<?php
/*
Plugin Name: JefThumbnails Size
Plugin URI:  www.jeffer.xyz
Description: 自动优化首页图片质量，提升加载速度
Version: 1.0
Author: Jeffer.Z
*/

// 防止直接访问
if (!defined('ABSPATH')) {
    exit;
}

class OptimizeThumbnails {
    private $options;
    private $default_single_size = 'large'; // 默认文章页使用large尺寸
    private $default_home_size = 'medium';  // 默认首页使用medium尺寸
    
    public function __construct() {
        // 初始化插件
        add_action('init', array($this, 'init'));
        
        // 注册激活和停用钩子
        register_activation_hook(__FILE__, array($this, 'activate'));
        register_deactivation_hook(__FILE__, array($this, 'deactivate'));
        
        // 添加后台菜单
        add_action('admin_menu', array($this, 'add_admin_menu'));
        add_action('admin_init', array($this, 'settings_init'));
        
        // 添加图片处理钩子
        add_filter('post_thumbnail_html', array($this, 'process_thumbnail'), 10, 3);
    }
    
    // 插件初始化
    public function init() {
        $this->options = get_option('ot_settings', array(
            'enable_home' => 1,
            'enable_single' => 1,
            'single_size' => $this->default_single_size,
            'home_size' => $this->default_home_size
        ));
    }
    
    // 插件激活时执行
    public function activate() {
        if (!get_option('ot_settings')) {
            add_option('ot_settings', array(
                'enable_home' => 1,
                'enable_single' => 1,
                'single_size' => $this->default_single_size,
                'home_size' => $this->default_home_size
            ));
        }
    }
    
    // 插件停用时执行
    public function deactivate() {
        // 清理设置
        delete_option('ot_settings');
        
        // 清理优化后的图片文件
        $upload_dir = wp_upload_dir();
        $files = glob($upload_dir['basedir'] . '/*-optimized-q*.*');
        if($files) {
            foreach($files as $file) {
                @unlink($file);
            }
        }
    }
    
    // 添加后台菜单
    public function add_admin_menu() {
        add_options_page(
            '缩略图优化设置',
            '缩略图优化',
            'manage_options',
            'optimize-thumbnails',
            array($this, 'render_settings_page')
        );
    }
    
    // 初始化设置
    public function settings_init() {
        register_setting('ot_options', 'ot_settings');
        
        add_settings_section(
            'ot_section',
            '缩略图优化设置',
            array($this, 'section_callback'),
            'optimize-thumbnails'
        );
        
        // 首页设置
        add_settings_field(
            'enable_home',
            '首页图片优化',
            array($this, 'render_enable_home_field'),
            'optimize-thumbnails',
            'ot_section'
        );
        
        // 首页图片尺寸设置
        add_settings_field(
            'home_size',
            '首页图片尺寸',
            array($this, 'render_home_size_field'),
            'optimize-thumbnails',
            'ot_section'
        );
        
        // 文章页设置
        add_settings_field(
            'enable_single',
            '文章页图片优化',
            array($this, 'render_enable_single_field'),
            'optimize-thumbnails',
            'ot_section'
        );
        
        // 文章页图片尺寸设置
        add_settings_field(
            'single_size',
            '文章页图片尺寸',
            array($this, 'render_single_size_field'),
            'optimize-thumbnails',
            'ot_section'
        );
    }
    
    // 渲染设置页面
    public function render_settings_page() {
        if (!current_user_can('manage_options')) {
            return;
        }
        ?>
        <div class="wrap">
            <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
            <form action="options.php" method="post">
                <?php
                settings_fields('ot_options');
                do_settings_sections('optimize-thumbnails');
                submit_button();
                ?>
            </form>
        </div>
        <?php
    }
    
    // 设置区域说明
    public function section_callback() {
        echo '<p>配置首页和文章页的图片优化设置。</p>';
        echo '<p>您可以分别为首页和文章页选择不同的图片尺寸。</p>';
        echo '<p>您可以在 设置->媒体 中查看和修改WordPress的缩略图尺寸设置。</p>';
    }
    
    // 渲染首页启用选项
    public function render_enable_home_field() {
        $enable_home = isset($this->options['enable_home']) ? $this->options['enable_home'] : 1;
        ?>
        <input type="checkbox" 
               name="ot_settings[enable_home]" 
               <?php checked($enable_home, 1); ?> 
               value="1">
        <p class="description">是否在首页启用图片优化</p>
        <?php
    }
    
    // 添加文章页启用选项渲染方法
    public function render_enable_single_field() {
        $enable_single = isset($this->options['enable_single']) ? $this->options['enable_single'] : 1;
        ?>
        <input type="checkbox" 
               name="ot_settings[enable_single]" 
               <?php checked($enable_single, 1); ?> 
               value="1">
        <p class="description">是否在文章页启用图片优化</p>
        <?php
    }
    
    // 添加文章页图片尺寸选项渲染方法
    public function render_single_size_field() {
        $single_size = isset($this->options['single_size']) ? $this->options['single_size'] : $this->default_single_size;
        $sizes = array(
            'thumbnail' => '缩略图 (' . get_option('thumbnail_size_w') . 'x' . get_option('thumbnail_size_h') . ')',
            'medium' => '中等尺寸 (' . get_option('medium_size_w') . 'x' . get_option('medium_size_h') . ')',
            'large' => '大尺寸 (' . get_option('large_size_w') . 'x' . get_option('large_size_h') . ')',
            'full' => '原始尺寸'
        );
        ?>
        <select name="ot_settings[single_size]">
            <?php foreach ($sizes as $size => $label): ?>
                <option value="<?php echo esc_attr($size); ?>" 
                        <?php selected($single_size, $size); ?>>
                    <?php echo esc_html($label); ?>
                </option>
            <?php endforeach; ?>
        </select>
        <p class="description">选择文章页特色图片显示的尺寸</p>
        <?php
    }
    
    // 添加首页图片尺寸选项渲染方法
    public function render_home_size_field() {
        $home_size = isset($this->options['home_size']) ? $this->options['home_size'] : $this->default_home_size;
        $sizes = array(
            'thumbnail' => '缩略图 (' . get_option('thumbnail_size_w') . 'x' . get_option('thumbnail_size_h') . ')',
            'medium' => '中等尺寸 (' . get_option('medium_size_w') . 'x' . get_option('medium_size_h') . ')',
            'large' => '大尺寸 (' . get_option('large_size_w') . 'x' . get_option('large_size_h') . ')',
            'full' => '原始尺寸'
        );
        ?>
        <select name="ot_settings[home_size]">
            <?php foreach ($sizes as $size => $label): ?>
                <option value="<?php echo esc_attr($size); ?>" 
                        <?php selected($home_size, $size); ?>>
                    <?php echo esc_html($label); ?>
                </option>
            <?php endforeach; ?>
        </select>
        <p class="description">选择首页文章列表中显示的图片尺寸</p>
        <?php
    }
    
    // 处理缩略图
    public function process_thumbnail($html, $post_id, $post_thumbnail_id) {
        // 首页处理
        if (is_home() && isset($this->options['enable_home']) && $this->options['enable_home']) {
            $size = isset($this->options['home_size']) ? $this->options['home_size'] : $this->default_home_size;
            $sized_image = wp_get_attachment_image_src($post_thumbnail_id, $size);
            if ($sized_image) {
                $full_image_url = wp_get_attachment_url($post_thumbnail_id);
                return str_replace($full_image_url, $sized_image[0], $html);
            }
        }
        
        // 文章页处理
        if (is_single() && isset($this->options['enable_single']) && $this->options['enable_single']) {
            $size = isset($this->options['single_size']) ? $this->options['single_size'] : $this->default_single_size;
            $sized_image = wp_get_attachment_image_src($post_thumbnail_id, $size);
            if ($sized_image) {
                $full_image_url = wp_get_attachment_url($post_thumbnail_id);
                return str_replace($full_image_url, $sized_image[0], $html);
            }
        }
        
        return $html;
    }
    
    // 添加卸载钩子
    public static function uninstall() {
        if (!defined('WP_UNINSTALL_PLUGIN')) {
            exit;
        }
        
        // 清理所有插件数据
        delete_option('ot_settings');
        
        // 清理优化后的图片
        $upload_dir = wp_upload_dir();
        array_map('unlink', glob($upload_dir['basedir'] . '/*-optimized-q*.*'));
    }
}

// 注册卸载钩子
register_uninstall_hook(__FILE__, array('OptimizeThumbnails', 'uninstall'));

// 初始化插件
$optimize_thumbnails = new OptimizeThumbnails(); 